@@ -16,9 +16,15 @@ public enum WidgetRequestType {
 	SPLITCOLUMNPANEL,
 	MERGECOLUMNPANEL,
 	GROUPBYPANEL,
+	TIMEAGGREGATIONPANEL,
+	NORMALIZEPANEL,
+	DENORMALIZEPANEL,
 	LABELCOLUNPANEL,
 	CHANGETABLETYPEPANEL,
 	DUPLICATESROWSPANEL,
 	VALIDATIONSTASKSPANEL,
-	CURATIONBYREPLACEBATCHDIALOG;
+	CURATIONBYREPLACEBATCHDIALOG,
+	MONITORBACKGROUNDPANEL,
+	RESOURCESPANEL;
+	
 }
