@@ -10,7 +10,7 @@ package org.gcube.portlets.user.td.widgetcommonevent.shared.tr.column;
 public enum ColumnTypeCode {
 	ANNOTATION("ANNOTATION"), ATTRIBUTE("ATTRIBUTE"), CODE("CODE"), CODEDESCRIPTION(
 			"CODEDESCRIPTION"), CODENAME("CODENAME"), DIMENSION("DIMENSION"), MEASURE(
-			"MESAURE"), TIMEDIMENSION("TIMEDIMENSION");
+			"MEASURE"), TIMEDIMENSION("TIMEDIMENSION");
 
 	/**
 	 * @param text
